'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeAuthRequest = makeAuthRequest;
exports.makeAuthResponse = makeAuthResponse;

var _jsontokens = require('jsontokens');

var _index = require('../index');

require('isomorphic-fetch');

function makeAuthRequest(privateKey, domain_name) {
  var manifestURI = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  var redirectURI = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
  var scopes = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : [];
  var expiresAt = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : (0, _index.nextHour)().getTime();

  var token = null;

  if (domain_name === null) {
    throw new Error("Invalid app domain name");
  }
  if (manifestURI === null) {
    manifestURI = domain_name + '/manifest.json';
  }
  if (redirectURI === null) {
    redirectURI = domain_name;
  }

  /* Create the payload */
  var payload = {
    jti: (0, _index.makeUUID4)(),
    iat: Math.floor(new Date().getTime() / 1000), // JWT times are in seconds
    exp: Math.floor(expiresAt / 1000), // JWT times are in seconds
    iss: null,
    public_keys: [],
    domain_name: domain_name,
    manifest_uri: manifestURI,
    redirect_uri: redirectURI,
    scopes: scopes
  };

  if (privateKey === null) {
    /* Create an unsecured token and return it */
    token = (0, _jsontokens.createUnsecuredToken)(payload);
  } else {
    /* Convert the private key to a public key to an issuer */
    var publicKey = _jsontokens.SECP256K1Client.derivePublicKey(privateKey);
    payload.public_keys = [publicKey];
    var address = (0, _index.publicKeyToAddress)(publicKey);
    payload.iss = (0, _index.makeDIDFromAddress)(address);
    /* Sign and return the token */
    var tokenSigner = new _jsontokens.TokenSigner('ES256k', privateKey);
    token = tokenSigner.sign(payload);
  }

  return token;
}

function makeAuthResponse(privateKey) {
  var profile = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var username = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  var coreToken = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
  var expiresAt = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : (0, _index.nextMonth)().getTime();


  /* Convert the private key to a public key to an issuer */
  var publicKey = _jsontokens.SECP256K1Client.derivePublicKey(privateKey);
  var address = (0, _index.publicKeyToAddress)(publicKey);

  /* Create the payload */
  var payload = {
    jti: (0, _index.makeUUID4)(),
    iat: Math.floor(new Date().getTime() / 1000), // JWT times are in seconds
    exp: Math.floor(expiresAt / 1000), // JWT times are in seconds
    iss: (0, _index.makeDIDFromAddress)(address),
    public_keys: [publicKey],
    profile: profile,
    username: username,
    core_token: coreToken
  };

  /* Sign and return the token */
  var tokenSigner = new _jsontokens.TokenSigner('ES256k', privateKey);
  return tokenSigner.sign(payload);
}